KuralitUiAudioLevelEvent class

Mic input loudness (0.0 - 1.0). Used to drive waveform visuals.

Inheritance

Constructors

KuralitUiAudioLevelEvent(double level)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
level double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited