KuralitUiProductsEvent class
Structured entity response: products list.
- Inheritance
-
- Object
- KuralitUiEvent
- KuralitUiProductsEvent
Constructors
-
KuralitUiProductsEvent({String? title, required List<
KuralitProduct> items, String? followUpQuestion}) -
const
Properties
- followUpQuestion → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
KuralitProduct> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited